{
	"name" : "Products Attributes & Manufacturers",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Enterprise Specific Modules/Electronic Industries",
	"depends" : ["base", "account", "product", "stock"],
	"init_xml" : [],
	"demo_xml" : [],
	"description": "A module that add manufacturers and attributes on the product form",
	"update_xml" : ["product_electronic_view.xml"],
	"active": False,
	"installable": True
}
